@@ -40,43 +40,51 @@ typedef struct _ParoleFileClass ParoleFileClass;
 
 struct _ParoleFile
 {
-    GObject         		parent;
+    GObject             parent;
 };
 
 struct _ParoleFileClass
 {
-    GObjectClass 		parent_class;
+    GObjectClass        parent_class;
 };
 
-GType        			parole_file_get_type        	  (void) G_GNUC_CONST;
+GType           parole_file_get_type                (void) G_GNUC_CONST;
 
-ParoleFile       	       *parole_file_new             	  (const gchar *filename);
+ParoleFile     *parole_file_new                     (const gchar *filename);
 
-ParoleFile       	       *parole_file_new_with_display_name (const gchar *filename,
-								   const gchar *display_name);
-								   
-ParoleFile                 *parole_file_new_cdda_track (const gint track_num, const gchar *display_name);
-
-ParoleFile                 *parole_file_new_dvd_chapter (gint chapter_num, const gchar *display_name);
-								   
-
-void parole_file_set_custom_subtitles (const ParoleFile *file, gchar *suburi);
-
-void parole_file_set_dvd_chapter (const ParoleFile *file, gint dvd_chapter);
+ParoleFile     *parole_file_new_with_display_name   (const gchar *filename,
+                                                     const gchar *display_name);
                                    
-const gchar   G_CONST_RETURN   *parole_file_get_directory 	  (const ParoleFile *file) G_GNUC_PURE;
+ParoleFile     *parole_file_new_cdda_track          (const gint track_num, 
+                                                     const gchar *display_name);
 
-const gchar   G_CONST_RETURN   *parole_file_get_file_name 	  (const ParoleFile *file) G_GNUC_PURE;
+ParoleFile     *parole_file_new_dvd_chapter         (gint chapter_num, 
+                                                     const gchar *display_name);
+                                   
+void            parole_file_set_custom_subtitles    (const ParoleFile *file, gchar *suburi);
 
-const gchar   G_CONST_RETURN   *parole_file_get_display_name 	  (const ParoleFile *file) G_GNUC_PURE;
+void            parole_file_set_dvd_chapter         (const ParoleFile *file, gint dvd_chapter);
 
-const gchar   G_CONST_RETURN   *parole_file_get_uri 		  (const ParoleFile *file) G_GNUC_PURE;
+gint            parole_file_get_dvd_chapter         (const ParoleFile *file);
+                                   
+const gchar   
+G_CONST_RETURN *parole_file_get_directory           (const ParoleFile *file) G_GNUC_PURE;
 
-const gchar   G_CONST_RETURN   *parole_file_get_content_type      (const ParoleFile *file) G_GNUC_PURE;
+const gchar   
+G_CONST_RETURN *parole_file_get_file_name           (const ParoleFile *file) G_GNUC_PURE;
 
-const gchar   G_CONST_RETURN   *parole_file_get_custom_subtitles (const ParoleFile *file) G_GNUC_PURE;
+const gchar   
+G_CONST_RETURN *parole_file_get_display_name        (const ParoleFile *file) G_GNUC_PURE;
+
+const gchar   
+G_CONST_RETURN *parole_file_get_uri                 (const ParoleFile *file) G_GNUC_PURE;
+
+const gchar   
+G_CONST_RETURN *parole_file_get_content_type        (const ParoleFile *file) G_GNUC_PURE;
+
+const gchar   
+G_CONST_RETURN *parole_file_get_custom_subtitles    (const ParoleFile *file) G_GNUC_PURE;
 
-gint parole_file_get_dvd_chapter (const ParoleFile *file);
 
 G_END_DECLS
 
