@@ -35,13 +35,12 @@
 #include "parole-pl-parser.h"
 #include "data/mime/parole-mime-types.h"
 
-static char *playlist_mime_types[] = {
-    "audio/x-mpegurl",
-    "audio/playlist",
-    "audio/x-scpls",
-    "audio/x-ms-asx",
-    "application/xml",
-    "application/xspf+xml",
+static char *playlist_file_extensions[] = {
+    "*.asx",
+    "*.m3u",
+    "*.pls",
+    "*.wax",
+    "*.xspf"
 };
 
 /**
@@ -162,8 +161,8 @@ GtkFileFilter *parole_get_supported_files_filter (void)
     
     gtk_file_filter_set_name (filter, _("All supported files"));
     
-    for ( i = 0; i < G_N_ELEMENTS (playlist_mime_types); i++)
-        gtk_file_filter_add_mime_type (filter, playlist_mime_types[i]);
+    for ( i = 0; i < G_N_ELEMENTS (playlist_file_extensions); i++)
+        gtk_file_filter_add_pattern (filter, playlist_file_extensions[i]);
     
     return filter;
     
@@ -178,8 +177,8 @@ GtkRecentFilter *parole_get_supported_recent_files_filter (void)
     
     gtk_recent_filter_set_name (filter, _("All supported files"));
     
-    for ( i = 0; i < G_N_ELEMENTS (playlist_mime_types); i++)
-        gtk_recent_filter_add_mime_type (filter, playlist_mime_types[i]);
+    for ( i = 0; i < G_N_ELEMENTS (playlist_file_extensions); i++)
+        gtk_recent_filter_add_pattern (filter, playlist_file_extensions[i]);
     
     return filter;
     
@@ -205,8 +204,8 @@ GtkFileFilter   *parole_get_supported_playlist_filter   (void)
     
     gtk_file_filter_set_name (filter, _("Playlist files"));
     
-    for ( i = 0; i < G_N_ELEMENTS (playlist_mime_types); i++)
-        gtk_file_filter_add_mime_type (filter, playlist_mime_types[i]);
+    for ( i = 0; i < G_N_ELEMENTS (playlist_file_extensions); i++)
+        gtk_file_filter_add_pattern (filter, playlist_file_extensions[i]);
     
     return filter;
 }
